django\_analyses.migrations package
===================================

Submodules
----------

django\_analyses.migrations.0001\_initial module
------------------------------------------------

.. automodule:: django_analyses.migrations.0001_initial
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: django_analyses.migrations
   :members:
   :undoc-members:
   :show-inheritance:
